==> centreon-web-22.10.29.tar.gz: centreon-web-22.10.29/www/front_src/src/Authentication/Openid/translatedLabels.tsx <==
export const labelOpenIDConnectConfiguration = 'OpenID Connect Configuration';
export const labelDefineOpenIDConnectConfiguration =
  'Define OpenID Connect configuration';
export const labelRequired = 'Required';
export const labelInvalidURL = 'Invalid URL';
export const labelInvalidIPAddress = 'Invalid IP Address';
export const labelFailedToSaveOpenidConfiguration =
  'Failed to save OpenID Connect configuration';
export const labelOpenIDConnectConfigurationSaved =
  'OpenID Connect configuration saved';
export const labelEnableOpenIDConnectAuthentication =
  'Enable OpenID Connect authentication';
export const labelAuthenticationMode = 'Authentication mode';
export const labelTrustedClientAddresses = 'Trusted client addresses';
export const labelBlacklistClientAddresses = 'Blacklist client addresses';
export const labelBaseUrl = 'Base URL';
export const labelAuthorizationEndpoint = 'Authorization endpoint';
export const labelTokenEndpoint = 'Token endpoint';
export const labelIntrospectionTokenEndpoint = 'Introspection token endpoint';
export const labelUserInformationEndpoint = 'User information endpoint';
export const labelEndSessionEndpoint = 'End session endpoint';
export const labelScopes = 'Scopes';
export const labelLoginAttributePath = 'Login attribute path';
export const labelClientID = 'Client ID';
export const labelClientSecret = 'Client secret';
export const labelUseBasicAuthenticatonForTokenEndpointAuthentication =
  'Use basic authentication for token endpoint authentication';
export const labelDisableVerifyPeer = 'Disable verify peer';
export const labelOpenIDConnectOnly = 'OpenID Connect only';
export const labelMixed = 'Mixed';
export const labelEnableAutoImport = 'Enable auto import';
export const labelContactTemplate = 'Contact template';
export const labelEmailAttributePath = 'Email attribute path';
export const labelFullnameAttributePath = 'Fullname attribute path';
export const labelAtLeastOneOfTheTwoFollowingFieldsMustBeFilled =
  'At least one of the two following fields must be filled';
export const labelContactGroup = 'Contact group';
export const labelAtLeastOneAuthorizationIsRequired =
  'At least one authorization relation is required';
export const labelAuthorizationValue = 'Authorization value';
export const labelAccessGroup = 'Access group';
export const labelDefineRelationAuthorizationValueAndAccessGroup =
  'Define the relation between authorization value and access group';
export const labelDeleteRelation = 'Delete the relation';
export const labelAuthorizationKey = 'Authorization key';
export const labelAuthorizationSummary =
  'This section allows you to give authorizations in order to link an imported user to an access group.';
export const labelContactGroupFieldDescription = `${labelContactGroup}: Define a contact group for the imported user.`;
export const labelAuthorizationKeyIsDefined = `${labelAuthorizationKey}: The key`;
export const labelGroups = 'groups';
export const labelAuthorizationKeyDefinedByDefault =
  'is defined by default. You can define another one.';
export const labelDefineRelationsDescription = `${labelDefineRelationAuthorizationValueAndAccessGroup}: You can link an authorization value to an access group.`;
export const labelIfWeConsiderTheFollowingExample =
  'If we consider the following example in the JSON received from the authorization endpoint, a relation is defined between the value';
export const labelTechnical = 'technical';
export const labelAndAnAccessGroup = 'and an access group:';
export const labelEnableConditionsOnIdentityProvider =
  'Enable conditions on identity provider';
export const labelConditionsAttributePath = 'Conditions attribute path';
export const labelWhichEndpointTheConditionsAttributePathComeFrom =
  'Which endpoint does the conditions attribute path come from?';
export const labelIntrospectionEndpoint = 'Introspection endpoint';
export const labelUserIformation = 'User information';
export const labelOther = 'Other';
export const labelDefineAuthorizedConditionsValues =
  'Define authorized conditions values';
export const labelConditionValue = 'Condition value';
export const labelRolesMapping = 'Roles mapping';
export const labelWhichEndpointTheRolesAttributePathComeFrom =
  'Which endpoint does the roles attribute path come from?';
export const labelEnableAutoManagement = 'Enable automatic management';
export const labelApplyOnlyFirtsRole = 'Apply only first role';
export const labelRolesAttributePath = 'Roles attribute path';
export const labelDefineRelationBetweenRolesAndAcl =
  'Define the relation between roles and ACL access groups';
export const labelRoleValue = 'Role value';
export const labelAclAccessGroup = 'ACL access group';
export const labelDefineYourEndpoint = 'Define your endpoint';
export const labelGroupsAttributePath = 'Groups attribute path';
export const labelWhichEndpointTheGroupsAttributePathComeFrom =
  'Which endpoint does the groups attribute path come from?';
export const labelDefinedTheRelationBetweenGroupsAndContactGroups =
  'Define the relation between groups and contact groups';
export const labelGroupValue = 'Group value';
export const labelRedirectUrl = 'Redirect URL';

==> centreon-web-23.10.28.tar.gz: centreon-web-23.10.28/www/front_src/src/Authentication/Openid/translatedLabels.tsx <==
import { labelContactGroup } from '../shared/translatedLabels';

export const labelOpenIDConnectConfiguration = 'OpenID Connect Configuration';
export const labelDefineOpenIDConnectConfiguration =
  'Define OpenID Connect configuration';
export const labelRequired = 'Required';
export const labelInvalidURL = 'Invalid URL';
export const labelInvalidIPAddress = 'Invalid IP Address';
export const labelFailedToSaveOpenidConfiguration =
  'Failed to save OpenID Connect configuration';
export const labelOpenIDConnectConfigurationSaved =
  'OpenID Connect configuration saved';
export const labelEnableOpenIDConnectAuthentication =
  'Enable OpenID Connect authentication';
export const labelTrustedClientAddresses = 'Trusted client addresses';
export const labelBlacklistClientAddresses = 'Blacklist client addresses';
export const labelBaseUrl = 'Base URL';
export const labelAuthorizationEndpoint = 'Authorization endpoint';
export const labelTokenEndpoint = 'Token endpoint';
export const labelIntrospectionTokenEndpoint = 'Introspection token endpoint';
export const labelUserInformationEndpoint = 'User information endpoint';
export const labelEndSessionEndpoint = 'End session endpoint';
export const labelScopes = 'Scopes';
export const labelLoginAttributePath = 'Login attribute path';
export const labelClientID = 'Client ID';
export const labelClientSecret = 'Client secret';
export const labelUseBasicAuthenticatonForTokenEndpointAuthentication =
  'Use basic authentication for token endpoint authentication';
export const labelDisableVerifyPeer = 'Disable verify peer';
export const labelOpenIDConnectOnly = 'OpenID Connect only';
export const labelEmailAttributePath = 'Email attribute path';
export const labelFullnameAttributePath = 'Fullname attribute path';
export const labelAtLeastOneOfTheTwoFollowingFieldsMustBeFilled =
  'At least one of the two following fields must be filled';
export const labelAtLeastOneAuthorizationIsRequired =
  'At least one authorization relation is required';
export const labelAuthorizationValue = 'Authorization value';
export const labelAccessGroup = 'Access group';
export const labelDefineRelationAuthorizationValueAndAccessGroup =
  'Define the relation between authorization value and access group';
export const labelAuthorizationKey = 'Authorization key';
export const labelAuthorizationSummary =
  'This section allows you to give authorizations in order to link an imported user to an access group.';
export const labelContactGroupFieldDescription = `${labelContactGroup}: Define a contact group for the imported user.`;
export const labelAuthorizationKeyIsDefined = `${labelAuthorizationKey}: The key`;
export const labelGroups = 'groups';
export const labelAuthorizationKeyDefinedByDefault =
  'is defined by default. You can define another one.';
export const labelDefineRelationsDescription = `${labelDefineRelationAuthorizationValueAndAccessGroup}: You can link an authorization value to an access group.`;
export const labelIfWeConsiderTheFollowingExample =
  'If we consider the following example in the JSON received from the authorization endpoint, a relation is defined between the value';
export const labelTechnical = 'technical';
export const labelAndAnAccessGroup = 'and an access group:';
export const labelWhichEndpointTheConditionsAttributePathComeFrom =
  'Which endpoint does the conditions attribute path come from?';
export const labelIntrospectionEndpoint = 'Introspection endpoint';
export const labelUserIformation = 'User information';
export const labelOther = 'Other';
export const labelWhichEndpointTheRolesAttributePathComeFrom =
  'Which endpoint does the roles attribute path come from?';
export const labelDefineRelationBetweenRolesAndAcl =
  'Define the relation between roles and ACL access groups';
export const labelDefineYourEndpoint = 'Define your endpoint';
export const labelWhichEndpointTheGroupsAttributePathComeFrom =
  'Which endpoint does the groups attribute path come from?';
export const labelDefinedTheRelationBetweenGroupsAndContactGroups =
  'Define the relation between groups and contact groups';
export const labelGroupValue = 'Group value';
export const labelRedirectUrl = 'Redirect URL';
